@@ -260,7 +260,7 @@ class DistributiveRepository:
     def getDistributiveByFile(self,filename):
         """Get Distributive object by filename"""
         # MAGIC_COMPRESS 0x000004 Check inside compressed files 
-        tf = typeFile(magic=0x6)
+        tf = typeFile(magic=0x6|0x20)
         ftype = tf.getMType(filename)
         if "block special" in ftype:
             return IsoDistributive(filename)
@@ -1202,9 +1202,10 @@ class SquashDistributive(Distributive):
 class IsoDistributive(Distributive):
     def __init__(self,file,parent=None,mdirectory="/mnt/cdrom",
             bdirectory="/var/calculate/tmp/iso",exclude=None,
-            compress="gzip"):
+            compress="gzip", volid="CALCULATE"):
         Distributive.__init__(self,parent=parent)
         self.file = file
+        self.volid = volid
         if path.isdir(self.file):
             self.mdirectory = self.file
         else:
@@ -1228,7 +1229,7 @@ class IsoDistributive(Distributive):
     def _mountIso(self,file,directory):
         if self.file != self.mdirectory:
             self._makeDirectory(directory)
-            tf = typeFile(magic=0x6)
+            tf = typeFile(magic=0x6|0x20)
             ftype = tf.getMType(file)
             if "block special" in ftype:
                 mopts = ""
@@ -1290,12 +1291,22 @@ class IsoDistributive(Distributive):
         if not path.exists(mkisoUtil):
             raise DistributiveError(_("Failed to create the iso image") +
                 " : %s"%_("command '%s' not found")%mkisoUtil)
+        efiImage = "boot/grub/efi.img"
+        if os.path.exists(os.path.join(directory,efiImage)):
+            params = ["-J","-R","-l","-no-emul-boot","-boot-load-size 4",
+                      "-udf","-boot-info-table","-b isolinux/isolinux.bin",
+                      "-V %s"%self.volid,
+                      "-c isolinux/boot.cat","-eltorito-alt-boot",
+                      "-no-emul-boot","-eltorito-platform efi",
+                      "-eltorito-boot %s"%efiImage]
+        else:
+            params = ["-b isolinux/isolinux.bin","-no-emul-boot",
+                    "-boot-load-size 4","-boot-info-table","-iso-level 4",
+                    "-hide boot.catalog"]
         res,errmes = self.runOsCommand(
             "%(progname)s %(params)s -o %(target)s %(source)s/"%
             {'progname':mkisoUtil,
-             'params':" ".join(["-b isolinux/isolinux.bin","-no-emul-boot",
-                    "-boot-load-size 4","-boot-info-table","-iso-level 4",
-                    "-hide boot.catalog"]),
+             'params':" ".join(params),
              'target':file,
              'source':directory})
         if res == 0:
