@@ -127,6 +127,9 @@ class Data:
     # system version
     os_linux_build = {'hide':True}
 
+    # files number
+    os_linux_filesnum = {'hide':True}
+
     # user login
     ur_login = {'hide':True}
 
