@@ -61,7 +61,8 @@ class GProgressBar(NoneProgressBar):
         title = re.sub("<[^>]+>", "", title)
         self.title = title
         if os.system('which Xdialog &>/dev/null') == 0:
-            pipe = subprocess.Popen('/usr/bin/Xdialog --progress "%s" 6 80'\
+            pipe = subprocess.Popen(
+                '/usr/bin/Xdialog --title="" --progress "%s" 6 80'\
                                     %(self.title),
                                     stdin=subprocess.PIPE,
                                     stdout=subprocess.PIPE,
@@ -83,8 +84,11 @@ class GProgressBar(NoneProgressBar):
 
     def _set(self,value):
         if self.pipein:
-            self.pipein.write("%02d\n"%value)
-            self.pipein.flush()
+            try:
+                self.pipein.write("%02d\n"%value)
+                self.pipein.flush()
+            except:
+                pass
 
     def setValue(self,value):
         '''Установить текущее значения для прогресса'''
