@@ -63,7 +63,7 @@ class encrypt(color_print):
         """
         if not password:
             self.printERROR(_("ERROR") + " getHashPasswd: " +
-                            _("password empty"))
+                            _("empty password"))
             return False
 
         hashPwd = ""
@@ -113,11 +113,11 @@ class encrypt(color_print):
         else:
             if SecHashAlg in ("lm","nt"):
                 self.printERROR(_("ERROR") + " getHashPasswd: " +
-                            (_("Can not support '%s' crypto algorithm")
+                            (_("Failed to support '%s' crypto algorithm")
                             %SecHashAlg) + " " +  _("without py-smbpasswd"))
             else:
                 self.printERROR(_("ERROR") + " getHashPasswd: " +
-                            _("Can not support '%s' crypto algorithm")
+                            _("Failed to support '%s' crypto algorithm")
                             %SecHashAlg)
             return False
         return hashPwd
@@ -257,7 +257,7 @@ nsCertType         = %(nsCertType)s
     def createCnfFile(self, textCnf):
         '''Generate openssl.cnf file'''
         if not os.path.exists(self.sslFile):
-            self.printERROR(_("Can not found %s")%self.sslFile)
+            self.printERROR(_("%s not found")%self.sslFile)
             return False
         strData = time.strftime("%Y%m%d%H%M%S",time.localtime(time.time()))
         cnfFileName = "%s.%s.cnf" %(strData,genpassword())
@@ -309,7 +309,7 @@ nsCertType         = %(nsCertType)s
         try:
             pwdObj = pwd.getpwnam(userName)
         except:
-            self.printERROR(_("Not found user %s")%userName)
+            self.printERROR(_("User %s not found")%userName)
             return False
         uid = pwdObj.pw_uid
         gid = pwdObj.pw_gid
@@ -411,7 +411,7 @@ nsCertType         = %(nsCertType)s
         try:
             pwdObj = pwd.getpwnam(userName)
         except:
-            self.printERROR(_("Not found user %s")%userName)
+            self.printERROR(_("User %s not found")%userName)
             return False
         uid = pwdObj.pw_uid
         gid = pwdObj.pw_gid
@@ -513,7 +513,7 @@ nsCertType         = %(nsCertType)s
         try:
             pwdObj = pwd.getpwnam(userName)
         except:
-            self.printERROR(_("Not found user %s")%userName)
+            self.printERROR(_("User %s not found")%userName)
             return False
         uid = pwdObj.pw_uid
         gid = pwdObj.pw_gid
@@ -540,7 +540,7 @@ nsCertType         = %(nsCertType)s
                             %(self.sslFile, cnfFile, sslDays, certFile,
                               keyFile))
         if textLine is False:
-            self.printERROR(_("Can not create certificate %s")%certFile)
+            self.printERROR(_("Failed to create certificate %s")%certFile)
             return False
         # Удаление конфигурационного файла
         if os.path.exists(cnfFile):
@@ -574,7 +574,7 @@ nsCertType         = %(nsCertType)s
         """
         dirName = os.path.split(fileName)[0]
         if not os.path.exists(dirName):
-            self.printERROR(_("Path %s not exists") %dirName)
+            self.printERROR(_("Path %s does not exist") %dirName)
             return False
         fd = os.open(fileName, os.O_CREAT)
         os.close(fd)
